---
title: 일반결제 연동하기
description: 우커머스 플러그인을 통해 일반결제를 연동합니다.
targetVersions:
  - v1
---

이 문서는 우커머스 플러그인을 사용하여 일반결제 기능을 연동하는 방법을 설명합니다.

## STEP1: 포트원SDK 버전 설정하기

워드프레스 관리자 페이지의 우커머스 > 설정 > 포트원 페이지로 이동합니다. 인증결제를 위해 SDK버젼 설정이 필요합니다.

(관련 이미지 첨부)

## STEP2: 결제 수단 활성화하기

워드프레스 관리자 페이지의 우커머스 > 설정 > 결제 페이지로 이동합니다. 사용하고자 하는 포트원 결제 수단을 활성화하고 관리 버튼을 통해 설정 페이지로 이동합니다.

(관련 이미지 첨부)

## STEP3: 고객사 정보 입력하기

포트원 관리자 콘솔 > 결제연동 > 내 식별정보에서 확인한 고객사 정보를 입력합니다. 변경 사항 저장 버튼을 눌러 설정 내용을 저장합니다.

(관련 이미지 첨부)

## STEP4: PG사 및 상점아이디 설정하기

연동하실 PG사와 PG사의 상점아이디를 입력해주세요.

(관련 이미지 첨부)

## STEP5: 결제 수단별 설정하기

결제 수단별 옵션들을 다음과 같이 설정할 수 있습니다.

### 신용카드, 카카오페이, PAYCO, Eximbay, Paymentwall

- 추가 옵션이 없습니다.

### 휴대폰 소액결제

- 디지털 상품: 실물이 아닌 디지털 상품은 활성화해야 합니다.

### 실시간 계좌이체

- 실시간 계좌이체 에스크로: 활성화하여 우커머스의 실시간 계좌이체 결제 수단을 에스크로 방식으로 변경할 수 있습니다.

### 가상계좌

- 가상계좌 에스크로: 활성화하여 우커머스의 가상계좌 결제 수단을 에스크로 방식으로 변경할 수 있습니다.
- 가상계좌 입금통지 설정: 가상계좌 입금통지를 받기 위해 반드시 설정해야 합니다. (필수)
- 사업자등록번호: 다날 - 신용카드/계좌이체/가상계좌를 PG사로 사용할때 반드시 입력해야 합니다.

<div class="hint" data-style="info">

가상계좌 입금통지 설정

가상계좌를 사용하는 경우에는 가상계좌 입금통지 설정을 반드시 설정해야 합니다.

</div>
